@@ -27,17 +27,15 @@
 #ifndef AMORANIM_H 
 #define AMORANIM_H 
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif 
+#include <QtCore/QHash>
+#include <QtCore/QPoint>
+#include <QtCore/QSize>
+#include <QtCore/QStringList>
+#include <QtCore/QVector>
 
-#include <stdlib.h>
-#include <unistd.h>
-#include <qmemarray.h>
-#include <qdict.h>
-#include <qstringlist.h>
-#include <kconfigbase.h>
-#include <ksimpleconfig.h>
+class QPixmap;
+class KConfigGroup;
+class KConfig;
 
 //---------------------------------------------------------------------------
 //
@@ -46,7 +44,7 @@
 class AmorAnim
 {
 public:
-    AmorAnim(KConfigBase &config);
+    explicit AmorAnim(KConfigGroup &config);
     virtual ~AmorAnim();
 
     void reset()
@@ -71,20 +69,20 @@ public:
     const QPixmap *frame();
 
 protected:
-    void readConfig(KConfigBase &config);
+    void readConfig(KConfigGroup &config);
 
 protected:
-    unsigned int   mCurrent;        // current frame in sequence
+    int   mCurrent;        // current frame in sequence
     QStringList    mSequence;       // sequence of images to display
-    QMemArray<int>    mDelay;          // delay between frames
-    QMemArray<QPoint> mHotspot;        // the hotspot in a frame
-    QMemArray<int>    mMovement;       // the distance to move between frames
+    QVector<int>    mDelay;          // delay between frames
+    QVector<QPoint> mHotspot;        // the hotspot in a frame
+    QVector<int>    mMovement;       // the distance to move between frames
     int            mTotalMovement;  // the total distance this animation moves
     QSize          mMaximumSize;    // the maximum size of any frame
 };
 
 //---------------------------------------------------------------------------
-typedef QPtrList<AmorAnim> AmorAnimationGroup;
+typedef QList<AmorAnim*> AmorAnimationGroup;
 
 //---------------------------------------------------------------------------
 //
@@ -107,9 +105,9 @@ public:
 
 protected:
     QString           mPath;
-    KSimpleConfig     *mConfig;
+    KConfig     *mConfig;
     QSize             mMaximumSize; // The largest pixmap used
-    QDict<AmorAnimationGroup> mAnimations; // list of animation groups
+    QHash<QString, AmorAnimationGroup*> mAnimations; // list of animation groups
     bool              mStatic;	    // static image
 };
 
