@@ -27,12 +27,9 @@
 #ifndef AMORWIDGET_H 
 #define AMORWIDGET_H 
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif 
+#include <QtGui/QWidget>
 
-#include <kapplication.h>
-#include <qwidget.h>
+class QPixmap;
 
 //---------------------------------------------------------------------------
 //
